"""
randopass: strong random English-word passphrases
"""
__version__="0.0.4"

"""secrets package is used for randomness"""
import secrets

def getPass(length=4):
    """returns passphrase composed of _length_ random words (4 by default)"""
    return [secrets.choice(_randomWordsArr) for i in range(length)]

_randomWordsArr = ["zero", "midnight", "yard", "volume", "boat", "belly", "demand", "intelligence", "literacy", "voice", "miserable", "free", "growth", "residence", "apathy", "majority", "fast", "outline", "degree", "emphasis", "positive", "achieve", "achievement", "agreement", "history", "account", "recognize", "accumulation", "experience", "charge", "star", "hurt", "black", "admit", "concede", "admission", "thanks", "receipt", "friend", "get", "AIDS", "bitter", "delay", "stimulation", "exchange", "deal", "favour", "performance", "return", "production", "jest", "play", "activity", "solo", "player", "cast", "real", "advertising", "version", "dependence", "addition", "speech", "facility", "stick", "formal", "orthodox", "glue", "plaster", "tape", "set", "poison", "council", "division", "executive", "confession", "include", "warning", "teenager", "acceptance", "woman", "man", "notice", "progress", "lead", "opponent", "hardship", "adviser", "revolutionary", "function", "affair", "attachment", "association", "statement", "open", "tissue", "collection", "hostility", "fan", "shake", "excitement", "consensus", "peasant", "help", "support", "object", "wind", "broadcast", "cabin", "pilot", "wing", "plane", "alarm", "beer", "alcohol", "consciousness", "excuse", "extraterrestrial", "foreigner", "similar", "commitment", "bond", "comprehensive", "allocation", "compromise", "lonely", "distance", "directory", "index", "change", "height", "aluminium", "graduate", "romantic", "atmosphere", "dream", "ambition", "shell", "pardon", "quantity", "figure", "supply", "speed", "entertainment", "game", "funny", "parallel", "ancestor", "fox", "animal", "ankle", "birthday", "note", "program", "bother", "response", "expect", "expectation", "restless", "anxiety", "share", "factor", "flat", "stroke", "clothes", "attract", "sympathetic", "appeal", "seem", "debut", "look", "texture", "convenience", "engineer", "rub", "paint", "general", "date", "assessment", "estimate", "arrest", "permission", "spider", "random", "wall", "archive", "arch", "fire", "room", "argument", "line", "desert", "rise", "weapon", "sleeve", "tank", "smell", "garlic", "tease", "move", "provoke", "moving", "pack", "row", "timetable", "bow", "gallery", "reservoir", "craftsman", "painter", "art", "silver", "beg", "invite", "view", "attack", "battery", "assembly", "claim", "selection", "astonishing", "far", "forward", "runner", "sport", "front", "nuclear", "tin", "monstrous", "strike", "effort", "serve", "care", "costume", "culture", "lawyer", "draw", "cute", "attraction", "property", "gold", "auction", "sound", "sign", "aunt", "writer", "command", "regulation", "government", "car", "bus", "robot", "transmission", "motorist", "fall", "supplementary", "common", "conscious", "axis", "baby", "carriage", "nursery", "heel", "withdrawal", "suitcase", "sphere", "vote", "trivial", "patch", "band", "slam", "deposit", "failure", "feast", "banish", "tycoon", "drum", "fence", "bar", "trade", "basis", "baseball", "wrong", "rational", "democratic", "cellar", "essential", "infrastructure", "introduction", "cell", "principle", "foundation", "club", "bathtub", "bathroom", "wash", "battlefield", "resist", "represent", "float", "oppose", "suit", "know", "trail", "ride", "depend", "dare", "differ", "match", "like", "dominate", "love", "owe", "mind", "run", "belong", "beat", "host", "win", "lack", "worry", "drop", "bill", "kidney", "carry", "testify", "hold", "stand", "posture", "presence", "rhythm", "scramble", "grace", "salon", "wave", "increase", "conceive", "deteriorate", "sheet", "friendly", "start", "source", "captivate", "low", "absent", "present", "critical", "opposed", "hot", "outer", "salvation", "late", "swallow", "think", "roar", "noble", "native", "left", "bad", "flex", "turn", "curve", "flexible", "good", "advantage", "hook", "leave", "mourning", "shoulder", "siege", "engagement", "improve", "coffee", "wine", "drink", "prejudice", "bike", "offer", "large", "contract", "duck", "turkey", "call", "delivery", "pill", "morsel", "chip", "snack", "sting", "burn", "sword", "space", "cover", "blast", "combine", "approval", "pest", "flash", "obstacle", "brick", "forget", "slab", "vein", "mosquito", "inflate", "punch", "depressed", "blue", "flush", "heart", "muscle", "scale", "mass", "constituency", "lake", "appendix", "flesh", "guard", "kettle", "steam", "cheek", "bomb", "sandwich", "rib", "tooth", "dividend", "horn", "album", "notebook", "prosper", "stall", "loot", "dull", "adopt", "breast", "cap", "base", "avenue", "end", "border", "reward", "cow", "stadium", "ring", "electronics", "courage", "toast", "bread", "width", "shatter", "smash", "cereal", "discovery", "hiccup", "rest", "corruption", "workshop", "bulletin", "summary", "glimpse", "light", "brilliance", "lip", "prosecute", "bring", "generate", "introduce", "import", "create", "organize", "publish", "disclose", "update", "take", "glass", "spectrum", "reception", "leaflet", "fragment", "brother", "eyebrow", "review", "cruel", "champagne", "garage", "center", "architecture", "displace", "roll", "cluster", "nerve", "package", "cottage", "nonsense", "load", "rabbit", "pop", "split", "operation", "office", "counter", "agency", "burst", "fuss", "buttocks", "cigarette", "traffic", "carbon", "taxi", "conspiracy", "corpse", "disaster", "multiply", "month", "week", "request", "cancel", "predict", "card", "career", "calm", "crusade", "candidate", "frank", "wolf", "sail", "canvas", "ceiling", "able", "content", "memory", "capital", "execution", "impulse", "legend", "prisoner", "treat", "consideration", "shark", "wrist", "sketch", "waterfall", "precedent", "advance", "register", "barrel", "coffin", "hurl", "catalogue", "capture", "bracket", "nap", "ranch", "white", "cause", "nature", "kill", "offend", "pour", "pit", "crash", "fame", "planet", "orbit", "paper", "penny", "core", "headquarters", "wheat", "hemisphere", "ceremony", "parade", "funeral", "license", "neck", "straw", "necklace", "throne", "president", "champion", "title", "reform", "convert", "freeze", "switch", "role", "feature", "provincial", "hostile", "systematic", "poor", "loud", "plot", "chase", "talkative", "check", "cheque", "urge", "compound", "element", "reaction", "chemistry", "king", "chest", "main", "head", "adoption", "chorus", "chop", "helicopter", "Bible", "watch", "lump", "church", "slide", "film", "round", "condition", "reference", "quote", "orange", "block", "mayor", "tribe", "applaud", "bang", "confrontation", "mud", "pottery", "soap", "clarify", "acquit", "cut", "crack", "mercy", "fist", "bishop", "clerk", "smart", "tick", "snap", "customer", "climb", "climate", "cutting", "time", "close", "contact", "cupboard", "dress", "overall", "belt", "fool", "seize", "train", "coalition", "harsh", "coat", "code", "contemporary", "generation", "cafe", "proof", "knowledge", "belief", "judgment", "laser", "curl", "snub", "fish", "cold", "cooperate", "give", "tent", "raise", "wardrobe", "settlement", "rainbow", "mosaic", "chord", "land", "confront", "enter", "appear", "discover", "bait", "comfort", "comfortable", "leader", "memorial", "recommend", "transaction", "business", "commerce", "market", "committee", "board", "sense", "park", "infect", "write", "network", "compact", "company", "pity", "remunerate", "competence", "plaintiff", "finish", "perfect", "complication", "complex", "follow", "module", "behave", "constitution", "understand", "squeeze", "accountant", "calculation", "hardware", "menu", "mouse", "computing", "software", "computer", "hide", "design", "imagine", "notion", "concept", "embryo", "practical", "applied", "sacred", "personal", "domestic", "private", "definition", "last", "harmony", "coincide", "terms", "freedom", "danger", "improvement", "behavior", "experiment", "director", "south", "federation", "trust", "constellation", "impound", "battle", "fit", "adjust", "standard", "normal", "compliance", "praise", "representative", "link", "related", "node", "draft", "sanctuary", "agree", "product", "effect", "doubt", "courtesy", "thoughtful", "TRUE", "tight", "structure", "use", "infection", "bin", "cassette", "full", "pollution", "competition", "satisfaction", "race", "circumstance", "Europe", "pupil", "deny", "contradiction", "joystick", "recovery", "rule", "transition", "convince", "vehicle", "sentence", "fabricate", "biscuit", "herb", "oil", "pan", "pot", "cage", "partnership", "cooperative", "policeman", "hospitality", "cord", "right", "discipline", "decorative", "makeup", "price", "clique", "cotton", "sofa", "matter", "mole", "offset", "poll", "coup", "voucher", "brave", "seminar", "credit", "course", "curriculum", "direction", "warrant", "polite", "court", "designer", "bloody", "jealous", "colleague", "cattle", "gap", "wisecrack", "cunning", "craft", "crackpot", "crevice", "rotten", "appetite", "creep", "fold", "creation", "artist", "thinker", "literature", "credibility", "creed", "sailor", "prosecution", "record", "criticism", "crosswalk", "bend", "collapse", "squash", "gravel", "copper", "snuggle", "clue", "cucumber", "ethnic", "mug", "cabinet", "cup", "remedy", "suppress", "heal", "lock", "money", "damn", "swear", "pillow", "convention", "tradition", "reduce", "amputate", "crop", "carve", "skin", "fork", "sale", "pat", "sunrise", "dairy", "total", "ballet", "navy", "dark", "favourite", "style", "file", "track", "dawn", "anniversary", "holiday", "fog", "shock", "body", "hand", "lot", "franchise", "shortage", "consider", "expose", "behead", "death", "betray", "decade", "resolution", "classify", "refuse", "recession", "descent", "decay", "medal", "reduction", "order", "devote", "profound", "well", "carrot", "coma", "default", "nonremittal", "fault", "lemon", "payment", "temperature", "quality", "god", "extension", "censorship", "debate", "lace", "tasty", "pleasure", "please", "pleasant", "preach", "rescue", "challenge", "limit", "demonstration", "destruction", "thick", "density", "reliable", "describe", "subject", "exile", "bank", "depression", "rob", "commission", "lineage", "origin", "integration", "merit", "motif", "plan", "functional", "architect", "want", "despair", "sweet", "fate", "break", "point", "confine", "custody", "discourage", "weigh", "decisive", "hate", "explode", "explosion", "modernize", "abnormal", "instrument", "filter", "crown", "dialogue", "negotiation", "journal", "drown", "diet", "disagree", "mess", "difficulty", "excavation", "industry", "proportion", "decrease", "diplomatic", "management", "manager", "soil", "disability", "denial", "unpleasant", "separation", "disk", "dump", "study", "negative", "stop", "disco", "offense", "find", "incongruous", "digital", "consultation", "treatment", "contempt", "spirit", "mask", "pie", "dish", "disorder", "case", "chart", "quarrel", "difference", "neglect", "dismiss", "joint", "undress", "interrupt", "disturbance", "disagreement", "thesis", "deter", "mile", "aloof", "trait", "characteristic", "spread", "circulate", "quarter", "upset", "trench", "butterfly", "variety", "deviation", "even", "harm", "work", "doctor", "philosophy", "charter", "pound", "dollar", "goat", "dog", "chicken", "cultivate", "control", "contribution", "gate", "bell", "threshold", "dorm", "drug", "image", "ruin", "drain", "opera", "drama", "theater", "curtain", "pull", "tap", "tie", "diagram", "fear", "awful", "sip", "dribble", "drive", "quit", "heroin", "user", "rehearsal", "east", "north", "west", "ditch", "repeat", "length", "twilight", "responsibility", "obligation", "house", "home", "dynamic", "past", "mail", "world", "pole", "relief", "relaxation", "accessible", "tender", "distinct", "handy", "restaurant", "aid", "economist", "boom", "economics", "economy", "value", "margin", "bean", "onion", "corn", "building", "school", "influence", "effective", "egg", "self", "ego", "hip", "elbow", "old", "choose", "voter", "current", "electron", "hill", "lift", "elite", "banana", "articulate", "flag", "eagle", "utter", "glow", "sentiment", "pain", "stress", "conglomerate", "empirical", "authorise", "blank", "clear", "brain", "witch", "surround", "frame", "meeting", "favorable", "invasion", "restrain", "settle", "output", "acute", "conclusion", "terminal", "survival", "opposition", "fuel", "wrap", "wrestle", "mastermind", "technology", "concentration", "enjoy", "indulge", "expansion", "soldier", "registration", "plead", "penetrate", "tempt", "temptation", "solid", "burial", "entry", "access", "ticket", "twist", "environment", "era", "balance", "breakdown", "just", "ambiguous", "ambiguity", "delete", "error", "intensify", "adventure", "flight", "leak", "perfume", "habit", "institution", "admiration", "respect", "evening", "incident", "trouble", "eternal", "estate", "grounds", "contrary", "test", "screen", "inspector", "mine", "exclude", "fat", "sell", "redeem", "correspond", "correspondence", "proclaim", "exclusive", "monopoly", "justify", "example", "illustrate", "practice", "dominant", "exercise", "press", "show", "display", "museum", "emergency", "abstract", "elaborate", "area", "anticipation", "prospect", "eject", "spend", "feel", "authority", "expertise", "reason", "explain", "remark", "graphic", "exhibition", "complain", "explicit", "apology", "highway", "delicate", "reach", "society", "surface", "outside", "blackmail", "deport", "galaxy", "glasses", "lid", "silk", "material", "manufacture", "side", "grimace", "aspect", "beard", "fax", "parameter", "observation", "attention", "fairy", "miss", "overlook", "lose", "weakness", "absence", "sunshine", "forge", "illusion", "distort", "acquaintance", "kinship", "crystal", "agriculture", "model", "trick", "secure", "screw", "knot", "cream", "tired", "blame", "prefer", "progressive", "cower", "concern", "bold", "viable", "banquet", "agent", "toll", "desire", "unrest", "confidence", "proud", "cat", "criminal", "hen", "girl", "bitch", "queen", "mother", "iron", "ferry", "conception", "celebration", "story", "fibre", "character", "novel", "fight", "stuff", "fill", "occupy", "movie", "producer", "final", "fund", "treasurer", "convict", "clay", "powder", "sand", "thumb", "fastidious", "particular", "goal", "fireplace", "shoot", "rifle", "firefighter", "strong", "cousin", "initial", "beginning", "initiative", "freshman", "financial", "salmon", "aquarium", "fisherman", "healthy", "equip", "convulsion", "scene", "cook", "fee", "interest", "tile", "meat", "steward", "toss", "deck", "level", "stun", "floor", "vegetation", "plant", "dough", "spill", "lily", "variation", "chimney", "soar", "concentrate", "family", "folk", "conventional", "second", "cheese", "grain", "salad", "cheat", "reckless", "football", "trace", "marathon", "step", "boot", "offensive", "raid", "patience", "power", "camp", "impact", "force", "exotic", "chief", "deer", "prevent", "branch", "spin", "class", "shape", "ball", "format", "abandon", "strength", "castle", "accident", "coal", "spring", "wheel", "skeleton", "rack", "hotdog", "fraud", "monster", "relieve", "straight", "safe", "clean", "dry", "pure", "weight", "exempt", "release", "liberty", "halt", "frequency", "original", "clash", "refrigerator", "ally", "warm", "terrify", "medieval", "facade", "ice", "cherry", "apple", "defeat", "foot", "smoke", "official", "mushroom", "mold", "desk", "seat", "lamp", "rage", "joke", "choke", "profit", "make", "gallon", "risk", "net", "score", "top", "gas", "meet", "homosexual", "regard", "gear", "jelly", "diamond", "jewel", "gem", "sex", "category", "health", "productive", "mutation", "genetic", "exploration", "zone", "circle", "escape", "cope", "age", "abolish", "eliminate", "master", "arise", "outfit", "ghostwriter", "charity", "talented", "daughter", "bless", "define", "perform", "pay", "distribute", "thank", "spare", "resignation", "secretion", "marble", "glance", "shine", "gloom", "glare", "frown", "sticky", "sink", "retire", "happen", "accompany", "pass", "fail", "goalkeeper", "departure", "golf", "peanut", "charm", "bloodshed", "overeat", "extort", "ministry", "minister", "catch", "gradient", "mark", "drift", "rice", "grandfather", "grandmother", "grip", "hay", "scrape", "tip", "gravity", "cemetery", "major", "high", "produce", "green", "welcome", "grudge", "mill", "traction", "army", "background", "cooperation", "flock", "herd", "organisation", "fleet", "troop", "adult", "development", "ensure", "defend", "hypothesis", "direct", "guide", "guideline", "guilt", "innocent", "taste", "water", "inhabitant", "haircut", "hall", "hammer", "basket", "manual", "cart", "umbrella", "glove", "hang", "yearn", "coincidence", "difficult", "cash", "wood", "nut", "damage", "collar", "harvest", "harass", "rush", "have", "wear", "dine", "afford", "brown", "sour", "steep", "smooth", "sharp", "sensitive", "complete", "square", "deep", "short", "weak", "infinite", "mature", "meadow", "veil", "governor", "helmet", "clearance", "therapist", "pile", "listen", "rumor", "grief", "heat", "responsible", "service", "portion", "dome", "moment", "future", "reluctance", "retreat", "fever", "highlight", "extreme", "handicap", "interference", "employ", "slap", "pawn", "pig", "keep", "resort", "tube", "bubble", "excavate", "habitat", "housewife", "honor", "addicted", "tire", "basketball", "platform", "ward", "inn", "enemy", "firm", "hut", "hour", "husband", "color", "embrace", "giant", "act", "face", "arm", "humanity", "comedy", "hunting", "safari", "hunter", "suffer", "injury", "suffering", "cross", "theory", "preoccupation", "identity", "identification", "dialect", "lighter", "sick", "unlawful", "notorious", "fantasy", "projection", "picture", "copy", "huge", "exemption", "affect", "spoil", "fair", "jungle", "pressure", "flawed", "temporary", "tool", "brush", "issue", "jail", "unlikely", "momentum", "tense", "regular", "unanimous", "accurate", "central", "inch", "passive", "still", "dead", "helpless", "tendency", "list", "whole", "conflict", "incapable", "contain", "double", "few", "insurance", "bay", "separate", "needle", "need", "person", "morale", "single", "lazy", "incentive", "splurge", "cheap", "implicit", "childish", "virus", "hell", "hospital", "determine", "flu", "information", "recording", "rare", "violation", "consumption", "monk", "instinct", "heir", "first", "shot", "pioneer", "inquiry", "ask", "question", "dedicate", "bee", "indoor", "insistence", "fresh", "establish", "episode", "exception", "college", "teach", "lecture", "education", "teacher", "means", "deficiency", "abuse", "coverage", "policy", "premium", "guerrilla", "rebel", "rebellion", "unity", "news", "mean", "purpose", "intervention", "inside", "middle", "medium", "translate", "read", "spokesperson", "crossing", "period", "bowel", "fascinate", "suspicion", "feeling", "flood", "innovation", "stock", "reverse", "speculate", "detective", "investment", "guest", "physical", "anger", "publication", "exit", "loop", "twitch", "appointment", "athlete", "reporter", "voyage", "joy", "try", "litigation", "parachute", "judicial", "law", "judge", "justice", "deprive", "discreet", "piano", "child", "calorie", "favor", "lion", "affinity", "oven", "knee", "stab", "horse", "sweater", "experienced", "laboratory", "union", "maze", "ignorance", "ignorant", "shallow", "bald", "soft", "bare", "girlfriend", "secular", "island", "site", "ground", "landowner", "name", "lick", "theft", "cathedral", "tiger", "great", "river", "crowd", "stage", "range", "pumpkin", "whip", "endure", "permanent", "tension", "fashion", "crime", "grass", "save", "store", "leadership", "blade", "leaf", "thin", "jump", "academy", "resign", "farewell", "depart", "talk", "leftovers", "action", "trustee", "liability", "opinion", "jurisdiction", "trial", "verdict", "key", "legislation", "legislature", "continuation", "wound", "minor", "disappoint", "disappointment", "deadly", "letter", "hover", "dictionary", "licence", "lie", "biography", "revoke", "beam", "bulb", "pastel", "ignite", "blonde", "equal", "restrict", "diameter", "column", "language", "context", "connection", "soup", "eavesdrop", "torch", "essay", "fiction", "small", "alive", "accept", "enthusiasm", "resident", "social", "lend", "engine", "housing", "attic", "log", "implication", "linger", "strip", "ridge", "shaft", "bench", "monkey", "admire", "relax", "Sunday", "misplace", "sacrifice", "drawing", "speaker", "chin", "minimum", "fortune", "chance", "trunk", "timber", "lunch", "thrust", "grand", "intermediate", "machinery", "spell", "enlarge", "dimension", "maid", "post", "brand", "reproduce", "deliver", "impress", "guess", "activate", "bark", "enhance", "weave", "amuse", "obscure", "touch", "revise", "develop", "knit", "reconcile", "decide", "widen", "presentation", "father", "spite", "cancer", "mistreat", "finance", "exploit", "falsify", "laborer", "construct", "demonstrate", "march", "seal", "wild", "seller", "distributor", "proposal", "wedding", "marriage", "wife", "marsh", "wonder", "communist", "grind", "rally", "glacier", "domination", "chew", "concrete", "plastic", "mathematics", "equation", "grow", "maximum", "buffet", "way", "qualify", "measure", "beef", "pump", "dressing", "clinic", "medicine", "specimen", "symptom", "see", "conference", "qualified", "theme", "tune", "partner", "citizen", "memorandum", "learn", "crew", "threat", "attitude", "outlook", "refer", "merchant", "freighter", "cruelty", "deserve", "fun", "hypnothize", "steel", "wire", "metal", "subway", "city", "microphone", "bomber", "campaign", "occupation", "factory", "minute", "aware", "miner", "mislead", "distortion", "mixture", "cake", "air", "solution", "confusion", "groan", "pattern", "mild", "routine", "empire", "abbey", "grant", "coin", "allowance", "debt", "virtue", "ethics", "integrity", "morning", "breakfast", "gesture", "movement", "motivation", "motorcycle", "truck", "slogan", "mountain", "volcano", "go", "is", "as", "or", "oh", "in", "an", "of", "at", "if", "no", "my", "me", "to", "be", "so", "we", "he", "by", "on", "do", "up", "am", "us", "stir", "dance", "skate", "glide", "swipe", "bounce", "swing", "migration", "circulation", "cinema", "mobile", "multimedia", "mutter", "contraction", "composer", "piece", "orchestra", "concert", "dragon", "sodium", "appoint", "nomination", "tell", "channel", "lane", "narrow", "congress", "hair", "tongue", "sickness", "marine", "approach", "tidy", "requirement", "thirsty", "negligence", "ignore", "bargain", "neighbour", "cool", "nervous", "latest", "report", "headline", "night", "agile", "retired", "lost", "duke", "owl", "bat", "extinct", "article", "civilian", "objective", "average", "census", "relative", "indirect", "ordinary", "genuine", "unfortunate", "tough", "false", "slow", "modest", "public", "integrated", "inappropriate", "other", "loose", "raw", "hard", "mention", "warn", "reputation", "harmful", "reactor", "chain", "count", "number", "foster", "food", "approve", "oak", "fixture", "protest", "dirty", "stubborn", "reserve", "borrow", "available", "profession", "seasonal", "sea", "visual", "eye", "primary", "heavy", "long", "superior", "neutral", "oral", "diplomat", "twin", "senior", "nose", "bear", "leg", "page", "critic", "survivor", "trainer", "linear", "half", "tray", "window", "hole", "surgeon", "automatic", "aviation", "driver", "contrast", "choice", "mouth", "satellite", "agenda", "liver", "donor", "orgy", "decoration", "kit", "expenditure", "printer", "scandal", "overwhelm", "manage", "exaggerate", "revolution", "obese", "due", "possession", "rate", "elephant", "treaty", "bucket", "shame", "palm", "tract", "chaos", "gasp", "trouser", "heaven", "ideal", "paralyzed", "uncle", "parking", "word", "drawer", "member", "root", "colon", "thigh", "jaw", "unfair", "bride", "detail", "elapse", "perforate", "faint", "skip", "reject", "exceed", "aisle", "hallway", "passage", "passion", "graze", "pasture", "patent", "route", "terrace", "nationalist", "nationalism", "syndrome", "hesitate", "pause", "wage", "pension", "royalty", "rent", "peace", "fur", "punish", "retiree", "population", "hear", "observer", "percent", "insight", "absolute", "benefit", "performer", "century", "magazine", "cycle", "die", "allow", "vertical", "persist", "remain", "porter", "rider", "conductor", "vegetarian", "virgin", "slave", "patient", "witness", "consumer", "worker", "hero", "radical", "personality", "pin", "manner", "staff", "sweat", "basic", "operational", "dramatic", "throat", "telephone", "photograph", "camera", "wording", "evolution", "assault", "fitness", "size", "shelter", "physics", "broken", "prescription", "collect", "pluck", "photography", "print", "chalk", "bed", "field", "mechanism", "stereotype", "tablet", "dismissal", "organ", "urine", "slant", "arena", "bury", "insert", "mosque", "sow", "address", "put", "arrangement", "position", "braid", "layout", "Venus", "biology", "flower", "houseplant", "fossil", "weed", "sculpture", "panel", "pen", "fragrant", "attractive", "abundant", "shower", "feather", "looting", "dive", "asset", "poetry", "concession", "location", "extent", "corner", "arrow", "officer", "party", "ideology", "colony", "pyramid", "bacon", "dose", "part", "portrait", "easy", "orientation", "charismatic", "beautiful", "rich", "acquisition", "possibility", "station", "stamp", "tail", "possible", "potential", "pocket", "swarm", "flour", "hierarchy", "blow", "application", "realism", "sermon", "priority", "exact", "definite", "precision", "precede", "predator", "horoscope", "preference", "racism", "chauvinist", "assumption", "absorption", "training", "bake", "ready", "prevalence", "gift", "conservation", "jam", "administration", "presidency", "push", "lobby", "coerce", "glory", "prestige", "assume", "imposter", "mainstream", "quotation", "discount", "chimpanzee", "crude", "form", "prison", "hostage", "coach", "privacy", "award", "likely", "investigation", "process", "gradual", "perception", "announcement", "manufacturer", "professor", "uniform", "professional", "chair", "technique", "gain", "offspring", "forecast", "forbid", "ban", "throw", "missile", "prediction", "sustain", "pledge", "marketing", "remind", "launch", "pitch", "advocate", "quota", "advice", "suggest", "owner", "protection", "demonstrator", "pride", "entertain", "feed", "state", "soul", "analysis", "analyst", "psychology", "sensation", "forum", "publicity", "riot", "edition", "promotion", "publisher", "pool", "drag", "extract", "penalty", "student", "buy", "hobby", "button", "advertise", "lay", "instal", "install", "execute", "nominate", "earthquake", "dilemma", "prey", "satisfied", "pursuit", "problem", "quiet", "silence", "fraction", "Koran", "radio", "radiation", "xray", "railcar", "railroad", "storm", "rain", "breed", "build", "noise", "knock", "rape", "ecstasy", "rank", "preparation", "reality", "back", "new", "beneficiary", "mutual", "appreciate", "realize", "tolerate", "referral", "compensation", "document", "matrix", "correction", "recover", "loss", "red", "redundancy", "polish", "sugar", "elegant", "mirror", "reflection", "asylum", "garbage", "popular", "continental", "national", "presidential", "constitutional", "imperial", "cultural", "economic", "magnetic", "moral", "environmental", "ratio", "relation", "relevance", "faith", "comment", "commemorate", "retain", "shave", "relinquish", "restoration", "lease", "tenant", "fix", "meal", "refund", "repetition", "regret", "substitute", "reproduction", "answer", "storage", "map", "recycle", "reptile", "horror", "researcher", "qualification", "palace", "community", "ash", "immune", "conservative", "tolerant", "pneumonia", "lung", "feedback", "kneel", "brake", "constraint", "result", "revival", "revive", "retailer", "outlet", "revenge", "withdraw", "remember", "echo", "opposite", "reader", "reinforce", "wealth", "jockey", "entitlement", "copyright", "option", "fruit", "rear", "inflation", "venture", "ritual", "gown", "rock", "kitchen", "suite", "rotation", "path", "road", "carpet", "rugby", "finished", "flow", "country", "countryside", "undermine", "salesperson", "greeting", "irony", "moon", "stroll", "flavor", "pray", "dictate", "expression", "strikebreaker", "frighten", "spray", "landscape", "scheme", "system", "scholar", "session", "classroom", "forestry", "science", "despise", "scratch", "conscience", "bronze", "gossip", "harbor", "seek", "coast", "endorse", "mystery", "secretary", "patrol", "security", "visible", "seed", "recruit", "quest", "transparent", "gene", "section", "bite", "elect", "pick", "assertive", "vain", "paradox", "willpower", "spontaneous", "arrogant", "dignity", "autonomy", "export", "greet", "perceive", "humor", "ear", "reasonable", "sensitivity", "detector", "discriminate", "distant", "barrier", "scenario", "sequence", "series", "snake", "waiter", "established", "arrange", "apparatus", "strict", "stitch", "faithful", "shadow", "nuance", "feign", "embarrassment", "disgrace", "cylinder", "edge", "bundle", "bleed", "protect", "budge", "reflect", "horseshoe", "beach", "jacket", "shorts", "deficit", "abridge", "injection", "strap", "brag", "prove", "shrink", "bush", "shiver", "mix", "ostracize", "closed", "temple", "profile", "digress", "pavement", "symbol", "meaning", "important", "lover", "velvet", "flatware", "plain", "stool", "simplicity", "honest", "unit", "sin", "sister", "nun", "sit", "locate", "ample", "magnitude", "survey", "slip", "skilled", "scan", "freckle", "peel", "omission", "captain", "horizon", "angle", "killer", "murder", "bedroom", "steak", "stumble", "gaffe", "slippery", "dip", "slump", "slime", "snail", "bullet", "sleep", "particle", "berry", "pony", "limited", "packet", "sample", "scrap", "slot", "compartment", "village", "minority", "fine", "petty", "dash", "smile", "spot", "trap", "snatch", "kidnap", "snow", "serious", "gregarious", "ant", "welfare", "socialist", "civilization", "pudding", "worm", "casualty", "suspect", "communication", "wreck", "prince", "resource", "monarch", "bridge", "formation", "shout", "snarl", "whisper", "privilege", "audience", "hypothesize", "accent", "trance", "spit", "sector", "pepper", "shed", "angel", "divorce", "divide", "referee", "stain", "expand", "scatter", "encourage", "team", "waste", "crouch", "jet", "crutch", "staircase", "stake", "haunt", "stem", "stable", "norm", "sun", "begin", "situation", "safety", "relationship", "reliance", "isolation", "say", "declaration", "formula", "rung", "wait", "lodge", "constant", "plagiarize", "ladder", "stay", "pierce", "muggy", "miscarriage", "shareholder", "sock", "plug", "shop", "straighten", "strategic", "wander", "banner", "trolley", "struggle", "stretch", "hit", "kick", "stunning", "guitar", "ribbon", "conviction", "emotion", "vigorous", "cable", "tower", "nest", "auditor", "trip", "fashionable", "chapter", "paragraph", "soak", "replace", "suburb", "brainstorm", "inspiration", "evoke", "indication", "proper", "sulphur", "budget", "sum", "overview", "summer", "summit", "superintendent", "miracle", "dinner", "bag", "prayer", "cater", "inspire", "provide", "provision", "shelf", "pier", "inhibition", "overcharge", "certain", "excess", "deputy", "replacement", "defendant", "chocolate", "swell", "door", "shift", "swop", "understanding", "interactive", "calendar", "research", "salt", "table", "undertake", "tactic", "breathe", "insist", "inject", "eat", "absorb", "insure", "participate", "musical", "conversation", "discuss", "tree", "suntan", "candle", "duty", "assignment", "job", "bland", "tax", "species", "instruction", "tear", "rhetoric", "television", "mood", "disposition", "pace", "loan", "trend", "strain", "finger", "abortion", "district", "panic", "examination", "will", "tribute", "recommendation", "leash", "text", "grateful", "Mars", "tragedy", "theorist", "slice", "mist", "nail", "layer", "thread", "dilute", "combination", "thought", "spine", "idea", "brink", "flourish", "fling", "confuse", "bolt", "relate", "bind", "lean", "occasion", "youth", "reign", "season", "clock", "shy", "can", "topple", "tiptoe", "frog", "labour", "item", "liberal", "grave", "tone", "knife", "drill", "dentist", "roof", "place", "tumble", "agony", "torture", "add", "tournament", "doll", "dealer", "myth", "tread", "transfer", "transform", "freight", "fare", "transport", "rubbish", "fly", "swim", "visit", "rehabilitation", "jury", "triangle", "victory", "prize", "gutter", "truth", "loyalty", "vat", "pipe", "stomach", "tumour", "rotate", "ivory", "dozen", "year", "day", "string", "pair", "couple", "tropical", "incredible", "uncertainty", "reveal", "vague", "spy", "cave", "underline", "bottom", "minimize", "project", "unlike", "unique", "surprise", "discrimination", "thaw", "continuous", "lesson", "ton", "consolidate", "global", "different", "volunteer", "artificial", "live", "dangerous", "invisible", "blind", "rough", "crisis", "frozen", "premature", "strange", "illness", "unaware", "folklore", "promote", "hilarious", "nightmare", "urgency", "sweep", "walk", "interface", "mechanical", "useful", "sigh", "threaten", "vacuum", "valley", "evaluate", "worth", "avant", "garde", "disappear", "variable", "variant", "broccoli", "vegetable", "van", "rocket", "embark", "promise", "poem", "peak", "bottle", "veteran", "neighborhood", "winner", "video", "compete", "wake", "energy", "active", "ghost", "sight", "tourist", "appearance", "colorful", "vision", "singer", "soprano", "intention", "book", "election", "ballot", "exposure", "bet", "waist", "queue", "lounge", "hike", "stride", "pedestrian", "cane", "deprivation", "war", "bird", "guarantee", "laundry", "basin", "password", "fountain", "stream", "vessel", "acid", "fluctuation", "method", "lifestyle", "gun", "cry", "valid", "familiar", "wagon", "sniff", "linen", "extend", "pigeon", "wilderness", "winter", "hope", "retirement", "fade", "express", "feminine", "feminist", "forest", "courtship", "sheep", "term", "formulate", "solve", "employee", "studio", "decline", "respectable", "acceptable", "misery", "compose", "wriggle", "script", "message", "offender", "sausage", "photocopy", "annual", "scream", "amber", "calf", "kid", "boy", "lamb", "junior", "young", "breeze", "earthflax", "earthwax", "earwax", "eaux", "econobox", "efflux", "embox", "enfix", "epicalyx", "equinox", "ex", "executrix", "quaint"]



#!/usr/bin/env python3

import randopass
import sys

def main():
    numWords = 4
    args = [a for a in sys.argv[1:]]
    if(len(args)>0):
        numWords = args[0]
        try:
            numWords = int(args[0])
        except:
            print("invalid argument", file=sys.stderr)
            return
    phrase = ''.join(randopass.getPass(numWords))
    print('Passphrase:\n', phrase, file=sys.stdout)
    del phrase

if __name__ == "__main__":
    main()



# -*- coding: utf-8 -*-

from setuptools import setup, find_packages


with open('README.md') as f:
    readme = f.read()

# with open('LICENSE') as f:
    # license = f.read()

setup(
    name='randopass',
    version='0.0.4',
    description='Generate easy but secure passphrases',
    long_description=readme,
    long_description_content_type='text/markdown',
    author='Mike Willems',
    author_email='themikewillems@gmail.com',
    url='https://github.com/mikewillems/randopass',
    packages=find_packages(exclude=('tests', 'docs')),
    python_requires='>=3.5, <4',
    entry_points={
        'console_scripts':[
            'randopass=command_line:main',
        ],
    },
)
